Usage — lenstronomy 1.9.1 documentation

# Usage

To use lenstronomy in a project:

    import lenstronomy

## Getting started

The starting guide jupyter notebook leads through the main modules and design features of lenstronomy. The modular design of lenstronomy allows the user to directly access a lot of tools and each module can also be used as stand-alone packages.

## Example notebooks

We have made an extension module available at https://github.com/sibirrer/lenstronomy_extensions. You can find simple examle notebooks for various cases. The latest versions of the notebooks should be compatible with the recent pip version of lenstronomy.

- Units, coordinate system and parameter definitions in lenstronomy
- FITS handling and extracting needed information from the data prior to modeling
- Modeling a simple Einstein ring
- Quadrupoly lensed quasar modelling
- Double lensed quasar modelling
- Time-delay cosmography
- Source reconstruction and deconvolution with Shapelets
- Solving the lens equation
- Multi-band fitting
- Measuring cosmic shear with Einstein rings
- Fitting of galaxy light profiles, like e.g. GALFIT
- Quasar-host galaxy decomposition
- Hiding and seeking a single subclump
- Mock generation of realistic images with substructure in the lens
- Mock simulation API with multi color models
- Catalogue data modeling of image positions, flux ratios and time delays
- Example of numerical ray-tracing and convolution options
- Simulated lenses with populations generated by SkyPy